@@ -5,7 +5,6 @@
 #' @inheritParams text_to_flat_pd
 #' @return A nested parse table. See [tokenize()] for details on the columns
 #'   of the parse table.
-#' @importFrom purrr when
 #' @examples
 #' code <- "
 #' ab     <- 1L # some comment
@@ -22,11 +21,13 @@ compute_parse_data_nested <- function(text,
   parse_data$child <- rep(list(NULL), length(parse_data$text))
   pd_nested <- parse_data %>%
     nest_parse_data() %>%
-    flatten_operators() %>%
-    when(any(parse_data$token == "EQ_ASSIGN") ~ relocate_eq_assign(.), ~.) %>%
-    add_cache_block()
+    flatten_operators()
 
-  pd_nested
+  if (any(parse_data$token == "EQ_ASSIGN")) {
+    pd_nested <- relocate_eq_assign(pd_nested)
+  }
+
+  pd_nested %>% add_cache_block()
 }
 
 #' Creates a flat parse table with minimal initialization
@@ -51,70 +52,51 @@ text_to_flat_pd <- function(text, transformers, more_specs) {
     add_terminal_token_after() %>%
     add_stylerignore() %>%
     add_attributes_caching(transformers, more_specs = more_specs) %>%
-    drop_cached_children()
+    shallowify()
 }
 
 #' Add the block id to a parse table
 #'
 #' Must be after [nest_parse_data()] because requires a nested parse table as
 #' input.
-#' @param pd_nested A top level nest.
+#' @param pd_nested A top-level nest.
 #' @keywords internal
-#' @importFrom rlang seq2
 add_cache_block <- function(pd_nested) {
   if (cache_is_activated()) {
     pd_nested$block <- cache_find_block(pd_nested)
   } else {
-    pd_nested$block <- rep(1, length(pd_nested$block))
+    pd_nested$block <- rep(1L, length(pd_nested$block))
   }
   pd_nested
 }
 
-#' Drop all children of a top level expression that are cached
-#'
-#' Note that we do not cache top-level comments. Because package code has a lot
-#' of roxygen comments and each of them is a top level expression, checking is
-#' very expensive. More expensive than styling, because comments are always
-#' terminals.
-#' @param pd A top-level nest.
-#' @details
-#' Because we process in blocks of expressions for speed, a cached expression
-#' will always end up in a block that won't be styled again (usual case), unless
-#' it's on a line where multiple expressions sit and at least one is not styled
-#' (exception).
-#'
-#' **usual case: All other expressions in a block are cached**
+
+#' Shallowify the parse table
 #'
 #' Cached expressions don't need to be transformed with `transformers` in
-#' [parse_transform_serialize_r_block()], we simply return `text` for the top
-#' level token. For that
-#' reason, the nested parse table can, at the rows where these expressions are
-#' located, be shallow, i.e. it does not have to contain a child, because it
-#' will neither be transformed nor serialized anytime. This function drops all
-#' associated tokens except the top-level token for such expressions, which will
-#' result in large speed improvements in [compute_parse_data_nested()] because
-#' nesting is expensive and will not be done for cached expressions.
+#' [parse_transform_serialize_r_block()], we simply return `text` for the
+#' top-level token.
+#' @details
+#' Expressions that are cached are already styled correctly. We can make the
+#' parse table shallow at these locations, fully relying on the `text` column:
 #'
-#' **exception: Not all other expressions in a block are cached**
+#' * remove all children, as they are not needed anymore.
+#' * mark the expression as a terminal.
 #'
-#' As described in [cache_find_block()], expressions on the same line are always
-#' put into one block. If any element of a block is not cached, the block will
-#' be styled as a whole. If the parse table was made shallow (and the top level)
-#' expression is still marked as non-terminal, `text` will never be used in the
-#' transformation process and eventually lost. Hence, we must change the top
-#' level expression to a terminal. It will act like a comment in the sense that
-#' it is a fixed `text`.
-#'
-#' Because for the usual case, it does not even matter if the cached expression
-#' is a terminal or not (because it is not processed), we can safely set
-#' `terminal = TRUE` in general.
+#' @section Top-level comments:
+#' Note that we do not cache top-level comments. Because package code has a lot
+#' of roxygen comments and each of them is a top-level expression, checking is
+#' very expensive. More expensive than styling, because comments are always
+#' terminals. This will also yield large speed improvements in
+#' [compute_parse_data_nested()] because nesting is expensive and will not be
+#' done for cached expressions.
 #' @section Implementation:
 #' Because the structure of the parse table is not always "top-level expression
 #' first, then children", this function creates a temporary parse table that has
 #' this property and then extract the ids and subset the original parse table so
 #' it is shallow in the right places.
 #' @keywords internal
-drop_cached_children <- function(pd) {
+shallowify <- function(pd) {
   if (cache_is_activated()) {
     order <- order(pd$line1, pd$col1, -pd$line2, -pd$col2, as.integer(pd$terminal))
     pd_parent_first <- pd[order, ]
@@ -122,7 +104,11 @@ drop_cached_children <- function(pd) {
       split(cumsum(pd_parent_first$parent == 0L)) %>%
       map(find_pos_id_to_keep) %>%
       unlist(use.names = FALSE)
-    pd[pd$pos_id %in% pos_ids_to_keep, ]
+    shallow <- pd[pd$pos_id %in% pos_ids_to_keep, ]
+    shallow$terminal[shallow$is_cached] <- TRUE
+    # all cached expressions need to be marked as terminals because to
+    # [apply_stylerignore()], we rely on terminals only.
+    shallow
   } else {
     pd
   }
@@ -138,8 +124,8 @@ drop_cached_children <- function(pd) {
 #' use `split(cumsum(pd_parent_first$parent < 1L))` because then every top-level
 #' comment is an expression on its own and processing takes much longer for
 #' typical roxygen annotated code.
-#' @param pd A temporary top level nest where the first expression is always a
-#'   top level expression, potentially cached.
+#' @param pd A temporary top-level nest where the first expression is always a
+#'   top-level expression, potentially cached.
 #' @details
 #' Note that top-level comments **above** code have negative parents
 #' (the negative value of the parent of the code expression that follows after,
@@ -153,7 +139,7 @@ drop_cached_children <- function(pd) {
 #' @keywords internal
 find_pos_id_to_keep <- function(pd) {
   if (pd$is_cached[1L]) {
-    pd$pos_id[pd$parent <= 0]
+    pd$pos_id[pd$parent <= 0L]
   } else {
     pd$pos_id
   }
@@ -291,7 +277,7 @@ add_terminal_token_before <- function(pd_flat) {
 #' where all other attributes are initialized with
 #' [default_style_guide_attributes()] (when using [tidyverse_style()]) because
 #' for cached code, we don't build up the nested structure and leave it shallow
-#' (to speed up things), see also [drop_cached_children()].
+#' (to speed up things), see also [shallowify()].
 #' @inheritParams is_cached
 #' @describeIn add_token_terminal Initializes `newlines` and `lag_newlines`.
 #' @keywords internal
@@ -325,7 +311,7 @@ add_attributes_caching <- function(pd_flat, transformers, more_specs) {
 #' @keywords internal
 set_spaces <- function(spaces_after_prefix, force_one) {
   if (force_one) {
-    rep(1, length(spaces_after_prefix))
+    rep(1L, length(spaces_after_prefix))
   } else {
     pmax(spaces_after_prefix, 1L)
   }
@@ -342,7 +328,6 @@ set_spaces <- function(spaces_after_prefix, force_one) {
 #' @param pd_flat A flat parse table including both terminals and non-terminals.
 #' @seealso [compute_parse_data_nested()]
 #' @return A nested parse table.
-#' @importFrom purrr map2
 #' @keywords internal
 nest_parse_data <- function(pd_flat) {
   if (all(pd_flat$parent <= 0L)) {
