@@ -76,3 +76,29 @@ tetst(
     x
   }, 1 + +1
 )
+
+while ({
+  x
+}) {
+  f()
+}
+
+while ({
+  x
+}
+) {
+  f()
+}
+
+while (
+  {
+  x
+}) {
+  f()
+}
+
+while (
+  {x
+}) {
+  f()
+}
