@@ -84,3 +84,27 @@ tetst(
   },
   1 + +1
 )
+
+while ({
+  x
+}) {
+  f()
+}
+
+while ({
+  x
+}) {
+  f()
+}
+
+while ({
+  x
+}) {
+  f()
+}
+
+while ({
+  x
+}) {
+  f()
+}
